#!/usr/bin/env node
import {
  __dirname
} from "./chunk-E2PHHEDL.mjs";
import path from "node:path";
import { spawnSync } from "node:child_process";
import { program } from "commander";
import { bailWithError, generateReport, parseAdvisory } from "./index.js";
const templateCJSPath = path.resolve(__dirname, "../../templates/template.ejs");
const templateESMPath = new URL("../templates/template.ejs", import.meta.url).pathname;
program.option("-o, --output [output]", "output file", "yarn-audit.html").option("-t, --template [ejs file]", "ejs template file", global.__dirname ? templateCJSPath : templateESMPath).option("--fatal-exit-code", "exit with code 1 if vulnerabilities were found", false).parse();
console.info("Checking audit logs...");
let summary;
const options = program.opts();
const vulnerabilities = /* @__PURE__ */ new Map();
const { stdout } = spawnSync("yarn", ["--version"]);
const yarnMajorVersion = Number.parseInt(stdout.toString());
let text = "";
process.stdin.on("readable", function() {
  try {
    const chunk = this.read();
    if (chunk !== null) {
      text += chunk;
      const lines = text.split("\n");
      if (lines.length > 1) {
        let advisoryToVulnerabilities2 = function(advisory) {
          const newVulnerabilities = parseAdvisory(advisory);
          newVulnerabilities.forEach((newVulnerability) => {
            const { key } = newVulnerability;
            if (!vulnerabilities.has(key)) {
              vulnerabilities.set(key, newVulnerability);
            }
          });
        };
        var advisoryToVulnerabilities = advisoryToVulnerabilities2;
        text = lines.splice(-1, 1)[0];
        lines.forEach((line) => {
          if (yarnMajorVersion >= 2) {
            const auditAdvisoryData = JSON.parse(line);
            Object.values(auditAdvisoryData.advisories).forEach((rawAdvisory) => {
              advisoryToVulnerabilities2(rawAdvisory);
            });
            summary = auditAdvisoryData.metadata;
          } else {
            const auditAdvisoryData = JSON.parse(line);
            if (auditAdvisoryData.type === "auditAdvisory") {
              advisoryToVulnerabilities2(auditAdvisoryData.data.advisory);
            } else if (auditAdvisoryData.type === "auditSummary") {
              summary = auditAdvisoryData.data;
            }
          }
        });
      }
    }
  } catch (error) {
    bailWithError("Failed to parse YARN Audit JSON!", error, options.fatalExitCode);
  }
});
process.stdin.on("end", async function() {
  try {
    await generateReport(Array.from(vulnerabilities.values()), summary, options);
  } catch (error) {
    bailWithError(
      "Failed to generate report! Please report this issue to https://github.com/davityavryan/yarn-audit-html/issues",
      error,
      options.fatalExitCode
    );
  }
});
