"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var src_exports = {};
__export(src_exports, {
  bailWithError: () => bailWithError,
  generateReport: () => generateReport,
  parseAdvisory: () => parseAdvisory,
  renderReport: () => renderReport,
  writeReport: () => writeReport
});
module.exports = __toCommonJS(src_exports);
var import_node_fs = __toESM(require("node:fs"));
var import_ejs = __toESM(require("ejs"));
var import_marked = require("marked");
const bootstrapClassSeverityMap = {
  critical: "danger",
  high: "warning",
  moderate: "secondary",
  low: "primary",
  info: "info"
};
const severitySortPriority = Object.keys(bootstrapClassSeverityMap);
function parseAdvisory(advisory) {
  const vulnerabilities = {};
  advisory.findings.forEach((finding) => {
    const { version } = finding;
    const key = `${advisory.module_name}@${version}-${advisory.vulnerable_versions}-${advisory.created}.${advisory.cwe}`;
    if (!(key in vulnerabilities)) {
      vulnerabilities[key] = {
        ...advisory,
        key,
        version,
        paths: finding.paths
      };
    } else {
      vulnerabilities[key].paths = [...vulnerabilities[key].paths, ...finding.paths];
    }
  });
  Object.entries(vulnerabilities).forEach(([key, vulnerability]) => {
    vulnerabilities[key].paths = Array.from(new Set(vulnerability.paths));
  });
  return Object.values(vulnerabilities);
}
async function generateReport(vulnerabilities, summary, options) {
  vulnerabilities.sort(
    (left, right) => severitySortPriority.indexOf(left.severity) - severitySortPriority.indexOf(right.severity)
  );
  const report = await renderReport(
    {
      reportDate: /* @__PURE__ */ new Date(),
      vulnerabilities,
      summary: {
        vulnerabilities: Object.values(summary.vulnerabilities).reduce((sum, value) => sum + value, 0),
        totalDependencies: summary.totalDependencies
      }
    },
    options.template
  );
  await writeReport(options.output, report);
  if (vulnerabilities.length > 0) {
    console.info(`Found ${vulnerabilities.length} vulnerabilities. Report is saved in "${options.output}"`);
    if (options.fatalExitCode) {
      return process.exit(1);
    }
  } else {
    console.info("Congrats!!! No vulnerabilities found.");
  }
  return process.exit(0);
}
async function renderReport(data, template) {
  const htmlTemplate = await import_node_fs.default.promises.readFile(template, "utf8");
  return import_ejs.default.render(htmlTemplate, {
    data,
    formatDate: (dateStr) => new Date(dateStr).toLocaleString(),
    severityClass: (severity) => bootstrapClassSeverityMap[severity],
    markdown: import_marked.marked
  });
}
async function writeReport(outputPath, report) {
  await import_node_fs.default.promises.writeFile(outputPath, report, { encoding: "utf8" });
}
function bailWithError(message, error, isFatalExitCode) {
  console.error(`${message}
`, error);
  if (isFatalExitCode) {
    return process.exit(1);
  }
  return process.exit(0);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  bailWithError,
  generateReport,
  parseAdvisory,
  renderReport,
  writeReport
});
