import ejs from 'ejs';

type Severity = 'info' | 'low' | 'moderate' | 'high' | 'critical';
type RawAuditAdvisor = {
    access: string;
    created: string;
    cves: string[];
    cvss: {
        score: number;
        vectorString: string;
    };
    cwe: string[];
    deleted: boolean | null;
    findings: {
        version: string;
        paths: string[];
        dev?: boolean;
        optional?: boolean;
        bundled?: boolean;
    }[];
    found_by: {
        name: string;
    } | null;
    github_advisory_id?: string;
    id: number;
    metadata: {
        module_type: string;
        exploitability: number;
        affected_components: string;
    } | null;
    module_name: string;
    npm_advisory_id: null;
    overview: string;
    patched_versions: string;
    recommendation: string;
    references: string;
    reported_by: {
        name: string;
    } | null;
    severity: Severity;
    title: string;
    updated: string;
    url: string;
    vulnerable_versions: string;
};
type AuditAdvisor = RawAuditAdvisor & {
    key: string;
    version: string;
    paths: string[];
};
type AuditVulnerabilityCounts = Record<Severity, number>;
type AuditMetadata = {
    vulnerabilities: AuditVulnerabilityCounts;
    dependencies: number;
    devDependencies: number;
    optionalDependencies: number;
    totalDependencies: number;
};
type Options = {
    output: string;
    template: string;
    fatalExitCode: boolean;
};

declare function parseAdvisory(advisory: RawAuditAdvisor): AuditAdvisor[];
declare function generateReport(vulnerabilities: AuditAdvisor[], summary: AuditMetadata, options: Options): Promise<never>;
declare function renderReport(data: ejs.Data, template: string): Promise<string>;
declare function writeReport(outputPath: string, report: string): Promise<void>;
declare function bailWithError(message: string, error: Error, isFatalExitCode: boolean): never;

export { bailWithError, generateReport, parseAdvisory, renderReport, writeReport };
